enum Anchor {
Freestanding,
Method,
}Expand description
Where to put extracted function definition
Variants
Freestanding
Extract free function and put right after current top-level function
Method
Extract method and put right after current function in the impl-block