FunctionBody

Enum FunctionBody 

enum FunctionBody {
    Expr(Expr),
    Span {
        parent: StmtList,
        elements: RangeInclusive<SyntaxElement>,
        text_range: TextRange,
    },
}
Semantically same as ast::Expr, but preserves identity when using only part of the Block This is the future function body, the part that is being extracted.

Variants



Expr(Expr)



Span

Fields

parent: StmtList
elements: RangeInclusive<SyntaxElement>
text_range: TextRange

Implementations

Source

impl FunctionBody

fn parent(&self) -> Option<SyntaxNode>

fn node(&self) -> &SyntaxNode

fn extracted_from_trait_impl(&self) -> bool

fn descendants(&self) -> impl Iterator<Item = SyntaxNode>

fn descendant_paths(&self) -> impl Iterator<Item = Path>

fn from_expr(expr: Expr) -> Option<Self>

fn from_range(parent: StmtList, selected: TextRange) -> Option<FunctionBody>

fn indent_level(&self) -> IndentLevel

fn tail_expr(&self) -> Option<Expr>

fn preorder_expr(&self, cb: &mut dyn FnMut(WalkEvent<Expr>) -> bool)

fn walk_pat(&self, cb: &mut dyn FnMut(Pat))

fn text_range(&self) -> TextRange

fn contains_range(&self, range: TextRange) -> bool

fn precedes_range(&self, range: TextRange) -> bool

fn contains_node(&self, node: &SyntaxNode) -> bool

fn suggest_name(&self) -> Option<String>

Source

impl FunctionBody

fn analyze( &self, sema: &Semantics<'_, RootDatabase>, ) -> (FxIndexSet<Local>, Option<SelfParam>)

Analyzes a function body, returning the used local variables that are referenced in it as well as whether it contains an await expression.

fn analyze_container<'db>( &self, make: &SyntaxFactory, sema: &Semantics<'db, RootDatabase>, edition: Edition, trait_name: Option<Name>, ) -> Option<(ContainerInfo<'db>, bool)>

fn return_ty<'db>(&self, ctx: &AssistContext<'_, 'db>) -> Option<RetType<'db>>

fn ret_values<'a>( &self, ctx: &'a AssistContext<'_, '_>, ) -> impl Iterator<Item = OutlivedLocal> + 'a

Local variables defined inside body that are accessed outside of it

fn external_control_flow<'db>( &self, ctx: &AssistContext<'_, 'db>, container_info: &ContainerInfo<'db>, ) -> Option<ControlFlow<'db>>

Analyses the function body for external control flow.

fn extracted_function_params<'db>( &self, ctx: &AssistContext<'_, 'db>, container_info: &ContainerInfo<'db>, locals: FxIndexSet<Local>, ) -> Vec<Param<'db>>

find variables that should be extracted as params

Computes additional info that affects param type and mutability

fn has_usages_after_body(&self, usages: &LocalUsages) -> bool