fn local_outlives_body(
ctx: &AssistContext<'_, '_>,
body_range: TextRange,
local: Local,
) -> Option<OutlivedLocal>Expand description
Returns usage details if local variable is used after(outside of) body
fn local_outlives_body(
ctx: &AssistContext<'_, '_>,
body_range: TextRange,
local: Local,
) -> Option<OutlivedLocal>Returns usage details if local variable is used after(outside of) body